<?php
/**
 * Copyright 2004-2005 Cronosys, LLC <http://www.cronosys.com/>
 *
 * See the enclosed file LICENSE for license information (BSD). If you did not
 * receive this file, see http://cvs.horde.org/co.php/vilma/LICENSE.
 *
 * $Horde: vilma/lib/MailboxDriver.php,v 1.2 2005/01/03 14:35:42 jan Exp $
 *
 * @author  Jason M. Felice <jfelice@cronosys.com>
 * @version $Revision: 1.2 $
 * @package Vilma
 */
class MailboxDriver {

    var $_params;

    /**
     * @private
     */
    function MailboxDriver($params = array())
    {
        $this->_params = $params;
    }
    
    /**
     * Create a new mailbox driver instance.
     *
     * @param string $driver            the name of the driver to create an
     *                                  instance of
     * @param array $params             driver-specific parameters
     * @return object the new driver instance or a PEAR_Error:: instance
     */
    function &factory($driver, $params = array())
    {
        require_once VILMA_BASE . '/lib/MailboxDriver/' . $driver . '.php';
        $class = 'MailboxDriver_' . $driver;
        return $ret = &new $class($params);
    }

    /**
     * Return a mailbox driver instance with the specified params, creating
     * it if necessary.
     *
     * @param string $driver            the name of the driver to create an
     *                                  instance of
     * @param array $params             driver-specific parameters
     * @return object the new driver instance or a PEAR_Error:: instance
     */
    function &singleton($driver, $params = array())
    {
        static $cache;
        $key = serialize(array($driver, $params));
        if (!isset($cache[$key])) {
            $ret = &MailboxDriver::factory($driver, $params);
            if (is_a($ret, 'PEAR_Error')) {
                return $ret;
            }
            $cache[$key] = &$ret;
        }
        return $cache[$key];
    }

    /**
     * Create a new mailbox.
     *
     * This default implementation only returns an error.
     *
     * @param string $user          the name of the mailbox to create
     * @param string $domain        the name of the domain in which to create
     *                              the mailbox
     * @return mixed true or PEAR_Error:: instance.
     */
    function createMailbox($user, $domain)
    {
        require_once 'PEAR.php';
        return PEAR::raiseError(_("This driver cannot create mailboxes."));
    }

    /**
     * Delete an existing mailbox.
     *
     * This default implementation only returns an error.
     *
     * @param string $user          the name of the mailbox to delete
     * @param string $domain        the name of the domain in which to delete 
     *                              the mailbox
     * @return mixed true or PEAR_Error:: instance.
     */
    function deleteMailbox($user, $domain)
    {
        require_once 'PEAR.php';
        return PEAR::raiseError(_("This driver cannot delete mailboxes."));
    }

    /**
     * Check whether a mailbox exists and is set up properly.
     *
     * @param string $user          the name of the mailbox to check
     * @param string $domain        the mailbox's domain 
     * @return mixed true or PEAR_Error:: instance.
     */
    function checkMailbox($user, $domain)
    {
        return true;
    }

}
